@@ -275,12 +275,13 @@ class OneToOnePerturbation(Perturbation):
             detokenizer (Callable, optional): Function to detokenize tokens into instance data.
                 Defaults to default_detokenizer.        
         """
-        mapping_list = [(a, b) for a, b in set(list(itertools.combinations(mapping_list, 2)))]
-        return OneToManyPerturbation.from_tuples(mapping_list,
-                                                 label_from=label_from,
-                                                 label_to=label_to,
-                                                 tokenizer=tokenizer,
-                                                 detokenizer=detokenizer)
+        # TODO: add case-sensitivity
+        mapping_dict = {k: v for k, v in set(list(itertools.combinations(mapping_list, 2)))}
+        return OneToManyPerturbation.from_dictionary(mapping_dict,
+                                                     label_from=label_from,
+                                                     label_to=label_to,
+                                                     tokenizer=tokenizer,
+                                                     detokenizer=detokenizer)
 
     @classmethod
     def from_string(cls,
